/*
 Library for BMP085 Sensor
 */


#include "Arduino.h"
#include "Wire.h"
#include "HIHLib.h"

HIHLib::HIHLib()		// Contructor
{
}


bool HIHLib::begin()	// Calibration function
{
	return true;
}

void HIHLib::read_data(){


      hum_status = fetch_humidity_temperature(&H_data, &T_data);
      
	  RH = (float) H_data * 6.10e-3;
      T_C = (float) T_data * 1.007e-2 - 40.0;

      switch(hum_status)
      {
          case 0:  //Serial.println("Normal.");
					RH = RH;
					T_C = T_C;
                   break;
          case 1:  //Serial.println("Stale Data.");
					RH = 0;
					T_C = 0;
                   break;
          case 2:  //Serial.println("In command mode.");
					RH = 0;
					T_C = 0;
                   break;
          default: //Serial.println("Diagnostic."); 
					RH = 0;
					T_C = 0;
                   break; 
      }      
    
	

}


byte HIHLib::fetch_humidity_temperature(unsigned int *p_H_data, unsigned int *p_T_data)
{
      byte address, Hum_H, Hum_L, Temp_H, Temp_L, hum_status;
      unsigned int H_data, T_data;
      address = 0x27;;
      Wire.beginTransmission(address); 
      Wire.endTransmission();
      delay(100);
      
      Wire.requestFrom((int)address, (int) 4);
      Hum_H = Wire.read();
      Hum_L = Wire.read();
      Temp_H = Wire.read();
      Temp_L = Wire.read();
      Wire.endTransmission();
      
      hum_status = (Hum_H >> 6) & 0x03;
      Hum_H = Hum_H & 0x3f;
      H_data = (((unsigned int)Hum_H) << 8) | Hum_L;
      T_data = (((unsigned int)Temp_H) << 8) | Temp_L;
      T_data = T_data / 4;
      *p_H_data = H_data;
      *p_T_data = T_data;
      return(hum_status);
}
   
void HIHLib::print_float(float f, int num_digits)
{
    int f_int;
    int pows_of_ten[4] = {1, 10, 100, 1000};
    int multiplier, whole, fract, d, n;

    multiplier = pows_of_ten[num_digits];
    if (f < 0.0)
    {
        f = -f;
        Serial.print("-");
    }
    whole = (int) f;
    fract = (int) (multiplier * (f - (float)whole));

    Serial.print(whole);
    Serial.print(".");

    for (n=num_digits-1; n>=0; n--) // print each digit with no leading zero suppression
    {
         d = fract / pows_of_ten[n];
         Serial.print(d);
         fract = fract % pows_of_ten[n];
    }
}      





